@@ -299,21 +299,21 @@ class User(TwitterCommonModel):
     location = models.CharField(u'Location', max_length=100)
     time_zone = models.CharField(u'Time zone', max_length=100, null=True)
 
-    contributors_enabled = models.BooleanField(u'Contributors enabled')
-    default_profile = models.BooleanField(u'Default profile')
-    default_profile_image = models.BooleanField(u'Default profile image')
-    follow_request_sent = models.BooleanField(u'Follow request sent')
-    following = models.BooleanField(u'Following')
-    geo_enabled = models.BooleanField(u'Geo enabled')
-    is_translator = models.BooleanField(u'Is translator')
-    notifications = models.BooleanField(u'Notifications')
-    profile_use_background_image = models.BooleanField(u'Profile use background image')
-    protected = models.BooleanField(u'Protected')
-    verified = models.BooleanField(u'Verified')
+    contributors_enabled = models.BooleanField(u'Contributors enabled', default=False)
+    default_profile = models.BooleanField(u'Default profile', default=False)
+    default_profile_image = models.BooleanField(u'Default profile image', default=False)
+    follow_request_sent = models.BooleanField(u'Follow request sent', default=False)
+    following = models.BooleanField(u'Following', default=False)
+    geo_enabled = models.BooleanField(u'Geo enabled', default=False)
+    is_translator = models.BooleanField(u'Is translator', default=False)
+    notifications = models.BooleanField(u'Notifications', default=False)
+    profile_use_background_image = models.BooleanField(u'Profile use background image', default=False)
+    protected = models.BooleanField(u'Protected', default=False)
+    verified = models.BooleanField(u'Verified', default=False)
 
     profile_background_image_url = models.URLField(max_length=300)
     profile_background_image_url_https = models.URLField(max_length=300)
-    profile_background_tile = models.BooleanField()
+    profile_background_tile = models.BooleanField(default=False)
     profile_background_color = models.CharField(max_length=6)
     profile_banner_url = models.URLField(max_length=300)
     profile_image_url = models.URLField(max_length=300)
@@ -367,9 +367,9 @@ class Status(TwitterCommonModel):
 
     text = models.TextField()
 
-    favorited = models.BooleanField()
-    retweeted = models.BooleanField()
-    truncated = models.BooleanField()
+    favorited = models.BooleanField(default=False)
+    retweeted = models.BooleanField(default=False)
+    truncated = models.BooleanField(default=False)
 
     source = models.CharField(max_length=100)
     source_url = models.URLField(null=True)
